==> zope-zms_2.1.2.7.orig.tar.gz: zope-zms-2.1.2.7/_objinputs.py <==
###################################################################################################
# _objinputs.py
#
# $Id: _objinputs.py,v 1.5 2004/02/24 19:57:21 dnordmann Exp $
# $Name:  $
# $Author: dnordmann $
# $Revision: 1.5 $
#
# Implementation of class ObjInputs (see below).
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
###################################################################################################

# Imports.
from Globals import HTMLFile
# Product Imports.
import _globals


###################################################################################################
###################################################################################################
###
###   O B J E C T   I N P U T S
###
###################################################################################################
###################################################################################################
class ObjInputs:

  # ---------------------------------------------------------------------------------------------
  #  Richtext-Editor
  # ---------------------------------------------------------------------------------------------
  richedit_html = HTMLFile('rte/dtml/richedit', globals())
  rte_browse_files_html = HTMLFile('rte/dtml/rte_browse_files', globals())
  rte_browse_images_html = HTMLFile('rte/dtml/rte_browse_images', globals())
  rte_dlg_ins_image_html = HTMLFile('rte/dtml/rte_dlg_ins_image', globals())
  rte_dlg_ins_link_html = HTMLFile('rte/dtml/rte_dlg_ins_link', globals())
  rte_dlg_ins_table_html = HTMLFile('rte/dtml/rte_dlg_ins_table', globals())
  rte_dlg_ins_char_html = HTMLFile('rte/dtml/rte_dlg_ins_char', globals())
  rte_color_picker_html = HTMLFile('rte/dtml/rte_color_picker', globals())
  # JavaScript
  rte_js = HTMLFile('rte/dtml/rte_js', globals())
  rte_toolbar_js = HTMLFile('rte/dtml/rte_toolbar_js', globals())
  # VBScript
  rte_styles_vbs = HTMLFile('rte/dtml/rte_styles_vbs', globals())
  # Cascading StyleSheets
  rte_css = HTMLFile('rte/dtml/rte_css', globals())
  rte_syntax_css = HTMLFile('rte/dtml/rte_syntax_css', globals())


  # ---------------------------------------------------------------------------------------------
  #  ObjInputs.getDisabledText
  # ---------------------------------------------------------------------------------------------
  def getDisabledText(self, size, value):
    html = ''
    html += '<font class="form-element">'
    s_value = ''
    if value is not None:
      if type(value) is type([]):
        count = 0
      	for item in value:
          s_value += '%s<br>'%_globals.html_quote(item)
          count = count + 1
      else:
        s_value += '%s'%_globals.html_quote(value)
    for i in range(len(s_value),size+2):
      s_value += '&nbsp;'
    html += s_value
    html += '</font>'
    return html


  # ---------------------------------------------------------------------------------------------
  #  ObjInputs.getUrlInput:
  #
  #	@param fmName
  #	@param elName
  #	@param elTextName
  #	@param size
  #	@param value
  #	@param enabled
  #	@param REQUEST
  #	@param css	CSS-Class
  #	@return String
  # ---------------------------------------------------------------------------------------------
  def getUrlInput(self, fmName, elName, elTextName, size, value, enabled, REQUEST, css='form-element'):
    html = []
    html.append('<div class="%s">'%css)
    html.append(self.getTextInput(fmName,elName,size,value,'text',enabled,REQUEST,css))
    html.append('<input ')
    html.append(' class="%s"'%css)
    html.append(' type="submit"')
    html.append(' name="btn"')
    html.append(' value="..."')
    html.append(' onclick="return browseObjsBtnClick(\'%s\',\'%s\',\'%s\')"'%(fmName,elName,elTextName))
    html.append('>')
    html.append('</div>')
    ref_obj = self.getLinkObj(value,REQUEST)
    if ref_obj is not None:
      html.append('<div class="form-small">')
      html.append('<b>%s</b>: %s'%(self.getLangStr('ATTR_TARGET',REQUEST['manage_lang']),ref_obj.f_breadcrumbs(objectPathElements=ref_obj.breadcrumbs_obj_path(),no_icon=1,lang=REQUEST['lang'],manage_lang=REQUEST['manage_lang'],REQUEST=REQUEST)))
      html.append('</div>')
    return ''.join(html)


  # ---------------------------------------------------------------------------------------------
  #  ObjInputs.getEnumInput:
  #
  #	@param fmName
  #	@param elName
  # ---------------------------------------------------------------------------------------------
  def getEnumInput(self, fmName, elName, size, value, enum, enabled=1, REQUEST=None, css='form-element'):
    html = []
    html.append('<font class="%s">'%css)
    if size > 0:
      html.append(self.getTextInput(fmName,elName,size,value,'text',enabled,REQUEST,css))
    else:
      html.append(self.getHiddenInput(fmName,elName,value,'%sChange(this);'%elName))
    html.append('<input ')
    html.append(' class="%s"'%css)
    html.append(' type="submit"')
    html.append(' name="btn"')
    html.append(' value="..."')
    html.append(' onclick="return browseEnumBtnClick(\'%s\',\'%s\',\'%s\')"'%(fmName,elName,enum))
    html.append('>')
    html.append('</font>')
    return ''.join(html)


  # ---------------------------------------------------------------------------------------------
  #  getHiddenInput:
  #
  #	@param fmName
  #	@param elName
  #	@param value
  # ---------------------------------------------------------------------------------------------
  def getHiddenInput(self, fmName, elName, value, onchange=''):
    html = []
    html.append('<input ')
    html.append(' type="hidden"')
    html.append(' name="%s"'%elName)
    html.append(' value="%s"'%str(value))
    if onchange:
      html.append(' onchange="%s"'%onchange)
    html.append('>')
    return ''.join(html)


  # ---------------------------------------------------------------------------------------------
  #  getDateTimeInput:
  #
  #	@param fmName
  #	@param elName
  #	@param size
  #	@param value
  #	@param enabled
  #	@param REQUEST
  #	@param css	CSS-Class
  #	@return String
  # ---------------------------------------------------------------------------------------------
  def getDateTimeInput(self, fmName, elName, size, value, enabled, fmt_str, REQUEST, css='form-element'):
    html = []
    manage_lang = REQUEST['manage_lang']
    if value is not None and type(value) != type(''):
      value = self.getLangFmtDate(value,manage_lang,fmt_str)
    if value is not None and self.parseLangFmtDate(value) is None:
      value = ''
    if enabled:
      html.append('<span class="%s" title="%s">'%(css,self.getLangStr(fmt_str,manage_lang)))
      html.append(self.getTextInput(fmName,elName,size,value,'text',enabled,REQUEST,css))
      html.append('<a href="javascript:calendarBtnClick(\'%s\',\'%s\',\'%s\')" class="button">'%(fmName,elName,manage_lang))
      html.append('<img src="%sbtn_calendar.gif" alt="%s..." border="0" align="middle" />'%(self.MISC_ZMS,self.getLangStr('ATTR_CALENDAR',manage_lang)))
      html.append('</a>')
      html.append('</span>')
    else:
      html.append(self.getDisabledText(size,value))
    return ''.join(html)


  # ---------------------------------------------------------------------------------------------
  # 	getDateInput:
  #
  #	@param fmName
  #	@param elName
  #	@param value
  #	@param enabled
  #	@param REQUEST
  #	@param css	CSS-Class
  #	@return String
  # ---------------------------------------------------------------------------------------------
  def getDateInput(self, fmName, elName, value, enabled, REQUEST, css='form-element'):
    return self.getDateTimeInput(fmName=fmName,elName=elName,size=8,value=value,enabled=enabled,fmt_str='DATE_FMT',REQUEST=REQUEST,css=css)


  # ---------------------------------------------------------------------------------------------
  # 	getPasswordInput:
  #
  #	@param fmName
  #	@param elName
  #	@param size
  #	@param value
  #	@param enabled
  #	@param css	CSS-Class
  #	@return String
  # ---------------------------------------------------------------------------------------------
  def getPasswordInput(self, fmName, elName, size=15, value='', enabled=1, REQUEST=None, css='form-element'):
    return self.getTextInput(fmName,elName,size,value,'password',enabled,REQUEST,css)


  # ---------------------------------------------------------------------------------------------
  # 	getTextInput:
  #
  #	@param fmName
  #	@param elName
  #	@param size
  #	@param value (optional)
  #	@param type (optional: "text" or "password")
  #	@param css	CSS-Class
  #	@return String
  # ---------------------------------------------------------------------------------------------
  def getTextInput(self, fmName, elName, size=15, value='', type='text', enabled=1, REQUEST=None, css='form-element'):
    html = []
    if enabled:
      html.append('<span class="%s">'%css)
      html.append('<input ')
      html.append(' class="%s"'%css)
      html.append(' type="%s"'%type)
      html.append(' name="%s"'%elName)
      if value is not None:
        html.append(' value="%s"'%_globals.html_quote(value))
      html.append(' size="%i"'%size) # Netscape Navigator
      html.append(' style="font-style:normal; width=%ipx"'%(size*12)) # Internet Explorer
      html.append(' />')
      html.append('</span>')
    else:
      html.append(self.getDisabledText(size,value))
    return ''.join(html)

  # ---------------------------------------------------------------------------------------------
  # 	getSelect:
  #
  #	@param fmName
  #	@param elName
  #	@param value
  #	@param inputtype
  #	@param lang_str
  #	@param required
  #	@param optpl
  #	@param enabled
  #	@param REQUEST  	Http-Request
  #	@param css		CSS-Class
  #	@return String
  # ---------------------------------------------------------------------------------------------
  def getSelect(self, fmName, elName, value, inputtype, lang_str, required, optpl, enabled, REQUEST, css='form-element'):
    html = ''
    if enabled:
      html += self.f_selectInput(self,fmName=fmName,elName=elName,value=value,type=inputtype,lang_str=lang_str,required=required,optpl=optpl,css=css,REQUEST=REQUEST)
    else:
      for opt in optpl:
        if str(opt[0]) == str(value) or \
           (type(value) is type([]) and (opt[0] in value or str(opt[0]) in value)):
          html += '%s\n'%str(opt[1])
      html = self.getDisabledText(20,html)
    return html

  # ---------------------------------------------------------------------------------------------
  # 	getCheckbox:
  #
  #	@param fmName
  #	@param elName
  #	@param value
  #	@param enabled
  #	@param hidden           Add hidden Input-Field if not enabled
  #	@param REQUEST  	Http-Request
  #	@param css		CSS-Class
  #	@param extra		Extra-Parameters
  #	@return String
  # ---------------------------------------------------------------------------------------------
  def getCheckbox(self, fmName, elName, value, enabled, hidden, REQUEST, css='form-checkbox', extra=''):
    html = []
    checked = str(value) == '1'
    if enabled:
      html.append('<input ')
      html.append(' type="hidden"')
      html.append(' name="%s"'%elName)
      html.append(' value="%s"'%str(value))
      html.append(' />')
      html.append('<input ')
      html.append(' class="%s"'%css)
      html.append(' type="checkbox"')
      if checked: 
        html.append(' checked="checked"')
      html.append(' onclick="if (this.checked) { this.form.elements[\'%s\'].value=1; } else {this.form.elements[\'%s\'].value=0;};"'%(elName,elName))
      html.append(' />')
    else:
      html.append('<img alt="" border="0" align="middle"')
      html.append(' src="%scheckbox_disabled%i.gif"'%(self.MISC_ZMS,checked))
      html.append(' />')
      if hidden:
        html.append(self.getHiddenInput(fmName,elName,value))
    return ''.join(html)
    
  # ---------------------------------------------------------------------------------------------
  # 	getTextArea:
  #
  #	@param fmName
  #	@param elName
  #	@param cols
  #	@param rows
  #	@param value
  #	@param enabled
  #	@param REQUEST  	Http-Request
  #	@param css		CSS-Class
  #	@param wrap		Word-Wrap (on|off)
  #	@param extra		Extra-Parameters
  #	@return String
  # ---------------------------------------------------------------------------------------------
  def getTextArea(self, fmName, elName, cols, rows, value, enabled, REQUEST, css='form-element', wrap='on', extra=''):
    html = []
    if enabled:
      html.append('<font class="%s">'%css)
      html.append('<textarea ')
      html.append(' class="%s"'%css)
      html.append(' name="%s"'%elName)
      html.append(' cols="%i"'%cols) # Netscape Navigator
      html.append(' style="width:%ipx;"'%(cols*12)) # Internet Explorer
      html.append(' rows="%i"'%rows)
      html.append(' wrap="%s"'%wrap)
      html.append('%s>'%extra)
      if value is not None:
        if type(value) is type([]):
          for item in value:
            html.append('%s\n'%_globals.html_quote(item))
        else:
          html.append('%s'%_globals.html_quote(value))
      html.append('</textarea>')
      html.append('</font>')
      if type(value) is type(''):
        i = -1
        c = 0
        while 1:
          i = value.find('{$',i+1)
          j = value.find('}',i+1)
          if i < 0 or j < 0:
            break
          if c == 0:
            html.append('<table cellspacing="0" cellpadding="1" border="0" align="left">')
            html.append('<tr valign="top">')
            html.append('<td class="form-small" align="left"><b>%s</b>:</td>'%(self.getLangStr('ATTR_TARGET',REQUEST['manage_lang'])))
            html.append('<td class="form-small" align="left">')
          if c % 2 == 0:
            html.append('<div class="zmiTableRowEven">')
          else:
            html.append('<div class="zmiTableRowOdd">')
          html.append('<div class="form-small">')
          ref_url = value[i:j+1]
          ref_obj = self.getLinkObj(ref_url,REQUEST)
          if ref_obj is not None:
            html.append('<img src="%sinternal_link.gif" alt="" border="0" align="absmiddle"/> %s'%(self.MISC_ZMS,ref_obj.f_breadcrumbs(objectPathElements=ref_obj.breadcrumbs_obj_path(),no_icon=1,lang=REQUEST['lang'],manage_lang=REQUEST['manage_lang'],REQUEST=REQUEST)))
          else:
            html.append('<img src="%sinternal_link_broken.gif" alt="" border="0" align="absmiddle"/> %s'%(self.MISC_ZMS,ref_url))
          html.append('</div>')
          html.append('</div>')
          c = c + 1
        if c > 0:
          html.append('</td>')
          html.append('</tr>')
          html.append('</table>')
    else:
      html.append(self.getDisabledText(cols,value))
    return ''.join(html)

###################################################################################################

==> zope-zms_2.3.2b57a09.orig.tar.gz: zope-zms-2.3.2b57a09/_objinputs.py <==
###################################################################################################
# _objinputs.py
#
# $Id: _objinputs.py,v 1.7 2004/11/24 21:02:52 dnordmann Exp $
# $Name:  $
# $Author: dnordmann $
# $Revision: 1.7 $
#
# Implementation of class ObjInputs (see below).
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
###################################################################################################

# Imports.
from Globals import HTMLFile
# Product Imports.
import _globals


###################################################################################################
###################################################################################################
###
###   O B J E C T   I N P U T S
###
###################################################################################################
###################################################################################################
class ObjInputs:

  # ---------------------------------------------------------------------------------------------
  #  Richtext-Editor
  # ---------------------------------------------------------------------------------------------
  richedit_html = HTMLFile('rte/dtml/richedit', globals())
  rte_browse_files_html = HTMLFile('rte/dtml/rte_browse_files', globals())
  rte_browse_images_html = HTMLFile('rte/dtml/rte_browse_images', globals())
  rte_dlg_ins_image_html = HTMLFile('rte/dtml/rte_dlg_ins_image', globals())
  rte_dlg_ins_link_html = HTMLFile('rte/dtml/rte_dlg_ins_link', globals())
  rte_dlg_ins_table_html = HTMLFile('rte/dtml/rte_dlg_ins_table', globals())
  rte_dlg_ins_char_html = HTMLFile('rte/dtml/rte_dlg_ins_char', globals())
  rte_color_picker_html = HTMLFile('rte/dtml/rte_color_picker', globals())
  # JavaScript
  rte_js = HTMLFile('rte/dtml/rte_js', globals())
  rte_toolbar_js = HTMLFile('rte/dtml/rte_toolbar_js', globals())
  # VBScript
  rte_styles_vbs = HTMLFile('rte/dtml/rte_styles_vbs', globals())
  # Cascading StyleSheets
  rte_css = HTMLFile('rte/dtml/rte_css', globals())
  rte_syntax_css = HTMLFile('rte/dtml/rte_syntax_css', globals())


  # ---------------------------------------------------------------------------------------------
  #  ObjInputs.getDisabledText
  # ---------------------------------------------------------------------------------------------
  def getDisabledText(self, size, value, css='form-element'):
    html = []
    html.append('<font class="form-element"')
    html.append(' class="%s"'%css)
    html.append(' style="padding-top: 1px; background-color: #FEFEFE; color: #808080; border: 1px solid #CCCCCC; font-style:normal; width=%ipx"'%(size*12)) # Internet Explorer
    html.append('>')
    s_value = ''
    if value is not None:
      if type(value) is type([]):
        count = 0
      	for item in value:
          s_value += '%s<br/>'%_globals.html_quote(item)
          count = count + 1
      else:
        s_value += '%s'%_globals.html_quote(value)
    for i in range(len(s_value),size+2):
      s_value += '&nbsp;'
    html.append(s_value)
    html.append('</font>')
    return ''.join(html)


  # ---------------------------------------------------------------------------------------------
  #  ObjInputs.getUrlInput:
  #
  #	@param fmName
  #	@param elName
  #	@param elTextName
  #	@param size
  #	@param value
  #	@param enabled
  #	@param REQUEST
  #	@param css	CSS-Class
  #	@return String
  # ---------------------------------------------------------------------------------------------
  def getUrlInput(self, fmName, elName, elTextName, size, value, enabled, REQUEST, css='form-element'):
    html = []
    html.append('<div class="%s">'%css)
    html.append(self.getTextInput(fmName,elName,size,value,'text',enabled,REQUEST,css))
    html.append('<input ')
    html.append(' class="%s"'%css)
    html.append(' type="submit"')
    html.append(' name="btn"')
    html.append(' value="..."')
    html.append(' onclick="return browseObjsBtnClick(\'%s\',\'%s\',\'%s\')"'%(fmName,elName,elTextName))
    html.append('>')
    html.append('</div>')
    ref_obj = self.getLinkObj(value,REQUEST)
    if ref_obj is not None:
      html.append('<div class="form-small">')
      html.append('<b>%s</b>: %s'%(self.getLangStr('ATTR_TARGET',REQUEST['manage_lang']),ref_obj.f_breadcrumbs(objectPathElements=ref_obj.breadcrumbs_obj_path(),no_icon=1,lang=REQUEST['lang'],manage_lang=REQUEST['manage_lang'],REQUEST=REQUEST)))
      html.append('</div>')
    return ''.join(html)


  # ---------------------------------------------------------------------------------------------
  #  ObjInputs.getEnumInput:
  #
  #	@param fmName
  #	@param elName
  # ---------------------------------------------------------------------------------------------
  def getEnumInput(self, fmName, elName, size, value, enum, enabled=1, REQUEST=None, css='form-element'):
    html = []
    html.append('<font class="%s">'%css)
    if size > 0:
      html.append(self.getTextInput(fmName,elName,size,value,'text',enabled,REQUEST,css))
    else:
      html.append(self.getHiddenInput(fmName,elName,value,'%sChange(this);'%elName))
    html.append('<input ')
    html.append(' class="%s"'%css)
    html.append(' type="submit"')
    html.append(' name="btn"')
    html.append(' value="..."')
    html.append(' onclick="return browseEnumBtnClick(\'%s\',\'%s\',\'%s\')"'%(fmName,elName,enum))
    html.append('>')
    html.append('</font>')
    return ''.join(html)


  # ---------------------------------------------------------------------------------------------
  #  getHiddenInput:
  #
  #	@param fmName
  #	@param elName
  #	@param value
  # ---------------------------------------------------------------------------------------------
  def getHiddenInput(self, fmName, elName, value, onchange=''):
    html = []
    html.append('<input ')
    html.append(' type="hidden"')
    html.append(' name="%s"'%elName)
    html.append(' value="%s"'%str(value))
    if onchange:
      html.append(' onchange="%s"'%onchange)
    html.append('>')
    return ''.join(html)


  # ---------------------------------------------------------------------------------------------
  #  getDateTimeInput:
  #
  #	@param fmName
  #	@param elName
  #	@param size
  #	@param value
  #	@param enabled
  #	@param REQUEST
  #	@param css	CSS-Class
  #	@return String
  # ---------------------------------------------------------------------------------------------
  def getDateTimeInput(self, fmName, elName, size, value, enabled, fmt_str, REQUEST, css='form-element'):
    html = []
    manage_lang = REQUEST['manage_lang']
    if value is not None and type(value) != type(''):
      value = self.getLangFmtDate(value,manage_lang,fmt_str)
    if value is not None and self.parseLangFmtDate(value) is None:
      value = ''
    if enabled:
      html.append('<span class="%s" title="%s">'%(css,self.getLangStr(fmt_str,manage_lang)))
      html.append(self.getTextInput(fmName,elName,size,value,'text',enabled,REQUEST,css))
      html.append('<a href="javascript:calendarBtnClick(\'%s\',\'%s\',\'%s\')" class="button">'%(fmName,elName,manage_lang))
      html.append('<img src="%sbtn_calendar.gif" title="%s..." border="0" align="middle"/>'%(self.MISC_ZMS,self.getLangStr('ATTR_CALENDAR',manage_lang)))
      html.append('</a>')
      html.append('</span>')
    else:
      html.append(self.getDisabledText(size,value))
    return ''.join(html)


  # ---------------------------------------------------------------------------------------------
  # 	getDateInput:
  #
  #	@param fmName
  #	@param elName
  #	@param value
  #	@param enabled
  #	@param REQUEST
  #	@param css	CSS-Class
  #	@return String
  # ---------------------------------------------------------------------------------------------
  def getDateInput(self, fmName, elName, value, enabled, REQUEST, css='form-element'):
    return self.getDateTimeInput(fmName=fmName,elName=elName,size=8,value=value,enabled=enabled,fmt_str='DATE_FMT',REQUEST=REQUEST,css=css)


  # ---------------------------------------------------------------------------------------------
  # 	getPasswordInput:
  #
  #	@param fmName
  #	@param elName
  #	@param size
  #	@param value
  #	@param enabled
  #	@param css	CSS-Class
  #	@return String
  # ---------------------------------------------------------------------------------------------
  def getPasswordInput(self, fmName, elName, size=15, value='', enabled=1, REQUEST=None, css='form-element'):
    return self.getTextInput(fmName,elName,size,value,'password',enabled,REQUEST,css)


  # ---------------------------------------------------------------------------------------------
  # 	getTextInput:
  #
  #	@param fmName
  #	@param elName
  #	@param size
  #	@param value (optional)
  #	@param type (optional: "text" or "password")
  #	@param css	CSS-Class
  #	@return String
  # ---------------------------------------------------------------------------------------------
  def getTextInput(self, fmName, elName, size=15, value='', type='text', enabled=1, REQUEST=None, css='form-element', extra=''):
    html = []
    if enabled:
      html.append('<span class="%s">'%css)
      html.append('<input ')
      html.append(' class="%s"'%css)
      html.append(' type="%s"'%type)
      html.append(' name="%s"'%elName)
      html.append(' size="%i"'%size)
      if value is not None:
        html.append(' value="%s"'%_globals.html_quote(value))
      html.append(' style="width:%iem;"'%size)
      html.append(' %s/>'%extra)
      html.append('</span>')
    else:
      html.append(self.getDisabledText(size,value,css))
    return ''.join(html)

  # ---------------------------------------------------------------------------------------------
  # 	getSelect:
  #
  #	@param fmName
  #	@param elName
  #	@param value
  #	@param inputtype
  #	@param lang_str
  #	@param required
  #	@param optpl
  #	@param enabled
  #	@param REQUEST  	Http-Request
  #	@param css		CSS-Class
  #	@return String
  # ---------------------------------------------------------------------------------------------
  def getSelect(self, fmName, elName, value, inputtype, lang_str, required, optpl, enabled, REQUEST, css='form-element'):
    html = ''
    if enabled:
      html += self.f_selectInput(self,fmName=fmName,elName=elName,value=value,type=inputtype,lang_str=lang_str,required=required,optpl=optpl,css=css,REQUEST=REQUEST)
    else:
      for opt in optpl:
        if str(opt[0]) == str(value) or \
           (type(value) is type([]) and (opt[0] in value or str(opt[0]) in value)):
          html += '%s\n'%str(opt[1])
      html = self.getDisabledText(20,html)
    return html

  # ---------------------------------------------------------------------------------------------
  # 	getCheckbox:
  #
  #	@param fmName
  #	@param elName
  #	@param value
  #	@param enabled
  #	@param hidden           Add hidden Input-Field if not enabled
  #	@param REQUEST  	Http-Request
  #	@param css		CSS-Class
  #	@param extra		Extra-Parameters
  #	@return String
  # ---------------------------------------------------------------------------------------------
  def getCheckbox(self, fmName, elName, value, enabled, hidden, REQUEST, css='form-checkbox', extra=''):
    html = []
    checked = str(value) == '1'
    if elName.find(':int') > 0 and value in [True, False]:
      value = self.boolint(value)
    if enabled:
      html.append('<input ')
      html.append(' type="hidden"')
      html.append(' name="%s"'%elName)
      html.append(' value="%s"'%str(value))
      html.append(' />')
      html.append('<input ')
      html.append(' class="%s"'%css)
      html.append(' type="checkbox"')
      if checked: 
        html.append(' checked="checked"')
      html.append(' onclick="if (this.checked) { this.form.elements[\'%s\'].value=1; } else {this.form.elements[\'%s\'].value=0;};"'%(elName,elName))
      html.append(' />')
    else:
      html.append('<img title="" border="0" align="middle"')
      html.append(' src="%scheckbox_disabled%i.gif"'%(self.MISC_ZMS,checked))
      html.append(' />')
      if hidden:
        html.append(self.getHiddenInput(fmName,elName,value))
    return ''.join(html)
    
  # ---------------------------------------------------------------------------------------------
  # 	getTextArea:
  #
  #	@param fmName
  #	@param elName
  #	@param cols
  #	@param rows
  #	@param value
  #	@param enabled
  #	@param REQUEST  	Http-Request
  #	@param css		CSS-Class
  #	@param wrap		Word-Wrap (on|off)
  #	@param extra		Extra-Parameters
  #	@return String
  # ---------------------------------------------------------------------------------------------
  def getTextArea(self, fmName, elName, cols, rows, value, enabled, REQUEST, css='form-element', wrap='on', extra=''):
    html = []
    if enabled:
      html.append('<font class="%s">'%css)
      html.append('<textarea ')
      html.append(' class="%s"'%css)
      html.append(' name="%s"'%elName)
      html.append(' cols="%i"'%cols)
      html.append(' rows="%i"'%rows)
      html.append(' wrap="%s"'%wrap)
      html.append(' style="width:%iem;"'%cols)
      html.append('%s>'%extra)
      if value is not None:
        if type(value) is type([]):
          for item in value:
            html.append('%s\n'%_globals.html_quote(item))
        else:
          html.append('%s'%_globals.html_quote(value))
      html.append('</textarea>')
      html.append('</font>')
      if type(value) is type('') and not REQUEST.get('URL','').find('manage_customize') >= 0:
        i = -1
        c = 0
        while 1:
          i = value.find('{$',i+1)
          j = value.find('}',i+1)
          if i < 0 or j < 0:
            break
          if c == 0:
            html.append('<table cellspacing="0" cellpadding="1" border="0" align="left">')
            html.append('<tr valign="top">')
            html.append('<td class="form-small" align="left"><b>%s</b>:</td>'%(self.getLangStr('ATTR_TARGET',REQUEST['manage_lang'])))
            html.append('<td class="form-small" align="left">')
          if c % 2 == 0:
            html.append('<div class="zmiTableRowEven">')
          else:
            html.append('<div class="zmiTableRowOdd">')
          html.append('<div class="form-small">')
          ref_url = value[i:j+1]
          ref_obj = self.getLinkObj(ref_url,REQUEST)
          if ref_obj is not None:
            html.append('<img src="%sinternal_link.gif" title="" border="0" align="absmiddle"/> %s'%(self.MISC_ZMS,ref_obj.f_breadcrumbs(objectPathElements=ref_obj.breadcrumbs_obj_path(),no_icon=1,lang=REQUEST['lang'],manage_lang=REQUEST['manage_lang'],REQUEST=REQUEST)))
          else:
            html.append('<img src="%sinternal_link_broken.gif" title="" border="0" align="absmiddle"/> %s'%(self.MISC_ZMS,ref_url))
          html.append('</div>')
          html.append('</div>')
          c = c + 1
        if c > 0:
          html.append('</td>')
          html.append('</tr>')
          html.append('</table>')
    else:
      html.append(self.getDisabledText(cols,value))
    return ''.join(html)

###################################################################################################
